@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: procargs.h,v 1.6 1999/02/23 11:43:03 martin Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -29,12 +27,21 @@
 #include <glibtop.h>
 #include <glibtop/global.h>
 
-#include <glibtop/compat_10.h>
-#include <glibtop/array.h>
-
 BEGIN_LIBGTOP_DECLS
 
-#define glibtop_get_proc_args(array,pid) glibtop_get_proc_args_l(glibtop_global_server, array, pid)
+#define GLIBTOP_PROC_ARGS_SIZE		0
+
+#define GLIBTOP_MAX_PROC_ARGS		1
+
+typedef struct _glibtop_proc_args	glibtop_proc_args;
+
+struct _glibtop_proc_args
+{
+	u_int64_t	flags,
+		size;			/* GLIBTOP_PROC_ARGS_SIZE	*/
+};
+
+#define glibtop_get_proc_args(proc_args,pid,max_len) glibtop_get_proc_args_l(glibtop_global_server, proc_args, pid, max_len)
 
 #if GLIBTOP_SUID_PROC_ARGS
 #define glibtop_get_proc_args_r		glibtop_get_proc_args_p
@@ -42,19 +49,22 @@ BEGIN_LIBGTOP_DECLS
 #define glibtop_get_proc_args_r		glibtop_get_proc_args_s
 #endif
 
-char **
-glibtop_get_proc_args_l (glibtop *server, glibtop_array *array, pid_t pid);
+char *
+glibtop_get_proc_args_l (glibtop *server, glibtop_proc_args *buf,
+			 pid_t pid, unsigned max_len);
 
 #if GLIBTOP_SUID_PROC_ARGS
-int glibtop_init_proc_args_p (glibtop *server);
+void glibtop_init_proc_args_p (glibtop *server);
 
-char **
-glibtop_get_proc_args_p (glibtop *server, glibtop_array *array, pid_t pid);
+char *
+glibtop_get_proc_args_p (glibtop *server, glibtop_proc_args *buf,
+			 pid_t pid, unsigned max_len);
 #else
-int glibtop_init_proc_args_s (glibtop *server);
+void glibtop_init_proc_args_s (glibtop *server);
 
-char **
-glibtop_get_proc_args_s (glibtop *server, glibtop_array *array, pid_t pid);
+char *
+glibtop_get_proc_args_s (glibtop *server, glibtop_proc_args *buf,
+			 pid_t pid, unsigned max_len);
 #endif
 
 #ifdef GLIBTOP_NAMES
