@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: glibtop_server.h,v 1.8 1999/02/23 11:43:57 martin Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -47,8 +45,6 @@ BEGIN_LIBGTOP_DECLS
 #define GLIBTOP_SUID_PROC_ARGS		(1 << GLIBTOP_SYSDEPS_PROC_ARGS)
 #define GLIBTOP_SUID_PROC_MAP		(1 << GLIBTOP_SYSDEPS_PROC_MAP)
 #define GLIBTOP_SUID_NETLOAD		(1 << GLIBTOP_SYSDEPS_NETLOAD)
-#define GLIBTOP_SUID_NETINFO		(1 << GLIBTOP_SYSDEPS_NETINFO)
-#define GLIBTOP_SUID_INTERFACE_NAMES	(1 << GLIBTOP_SYSDEPS_INTERFACE_NAMES)
 #define GLIBTOP_SUID_PPP		(1 << GLIBTOP_SYSDEPS_PPP)
 
 END_LIBGTOP_DECLS
